@@ -36,8 +36,20 @@ impl ToTokens for InputWrapper {
             .collect::<Vec<_>>();
         let impl_serialize_default_variant = if let Some(default_variant) = &input.default_variant {
             let ident = &default_variant.ident;
-            quote! {
-                Self::#ident(ref s) => return serde::Serialize::serialize(s, serializer),
+            if default_variant.r#type.is_some() {
+                quote! {
+                    Self::#ident(ref s) => return serde::Serialize::serialize(s, serializer),
+                }
+            } else {
+                let mut name = ident.to_string();
+                if let Some(rename_all) = &input.rename_all {
+                    if let Some(rename_rule) = &rename_all.serialize {
+                        name = rename_rule.apply_to_variant(&name);
+                    }
+                }
+                quote! {
+                    Self::#ident => return serde::Serialize::serialize(#name, serializer),
+                }
             }
         } else {
             quote!()
@@ -66,8 +78,12 @@ impl ToTokens for InputWrapper {
             .map(|variant| {
                 let ident = &variant.ident;
                 if variant.skip_serializing == Some(true) {
-                    // TODO, match rename_all
-                    let name = ident.to_string();
+                    let mut name = ident.to_string();
+                    if let Some(rename_all) = &input.rename_all {
+                        if let Some(rename_rule) = &rename_all.serialize {
+                            name = rename_rule.apply_to_variant(&name);
+                        }
+                    }
                     quote! {
                         Self::#ident => write!(f, "{}", #name),
                     }
@@ -80,8 +96,20 @@ impl ToTokens for InputWrapper {
             .collect::<Vec<_>>();
         let impl_display_default_variant = if let Some(default_variant) = &input.default_variant {
             let ident = &default_variant.ident;
-            quote! {
-                Self::#ident(ref s) => write!(f, "{}", s),
+            if default_variant.r#type.is_some() {
+                quote! {
+                    Self::#ident(ref s) => write!(f, "{}", s),
+                }
+            } else {
+                let mut name = ident.to_string();
+                if let Some(rename_all) = &input.rename_all {
+                    if let Some(rename_rule) = &rename_all.serialize {
+                        name = rename_rule.apply_to_variant(&name);
+                    }
+                }
+                quote! {
+                    Self::#ident => write!(f, "{}", #name),
+                }
             }
         } else {
             quote!()
